@@ -25,6 +25,41 @@ LOWERCASE_RUSSIAN = set(list('абвгдеёжзийклмнопрстуфхцч
 UPPERCASE_RUSSIAN = set(list('АБВГДЕЁЖЗИЙКЛМНОПРСТУФХЦЧШЩЪЫЬЭЮЯ'))
 POTENTIAL_ACCENTS = set(list('АОУЫЭЯЕЮИ'))
 BAD_BEGINNINGS = set(['Мак', 'мак', "О'", 'о’', 'О’', "о'"])
+NO_BREAK_SEQUENCES = [
+    "а",
+    "без",
+    "в",
+    "где",
+    "для",
+    "же",
+    "за",
+    "и",
+    "или",
+    "из",
+    "из-за",
+    "к",
+    "как",
+    "на",
+    "над",
+    "не",
+    "ни",
+    "но",
+    "о",
+    "от",
+    "по",
+    "под",
+    "при",
+    "с",
+    "то",
+    "у",
+    "что",
+    "перед"
+]
+NO_BREAK_SEQUENCES_LEFT = [
+    "бы",
+    "ли",
+    "же"
+]
 
 re_bad_wsp_start = re.compile(r'^[{}]+'.format(''.join(WHITESPACE)))
 re_bad_wsp_end = re.compile(r'[{}]+$'.format(''.join(WHITESPACE)))
@@ -90,6 +125,18 @@ def get_dashes_right(s):
     return s
 
 
+def replace_no_break_spaces(s):
+    for sp in (NO_BREAK_SEQUENCES + [x.title() for x in NO_BREAK_SEQUENCES]):
+        r_from = "([ \u00a0]){sp} ".format(sp=sp)
+        r_to = "\g<1>{sp}\u00a0".format(sp=sp)
+        s = re.sub(r_from, r_to, s)
+    for sp in (NO_BREAK_SEQUENCES_LEFT + [x.title() for x in NO_BREAK_SEQUENCES_LEFT]):
+        r_from = " {sp}([ \u00a0])".format(sp=sp)
+        r_to = "\u00a0{sp}\g<1>".format(sp=sp)
+        s = re.sub(r_from, r_to, s)
+    return s
+
+
 def search_accent(s):
     return re.search("([а-яё])([АОУЫЭЯЕЮИ])([^А-ЯЁ])", s) or re.search(
         "[^А-ЯЁ]([А-ЯЁ])([АОУЫЭЯЕЮИ])([^А-ЯЁ])", s
